@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function
+
 import tweepy
 
 # == OAuth Authentication ==
@@ -11,21 +13,22 @@ consumer_key=""
 consumer_secret=""
 
 # The access tokens can be found on your applications's Details
-# page located at https://dev.twitter.com/apps (located 
+# page located at https://dev.twitter.com/apps (located
 # under "Your access token")
 access_token=""
 access_token_secret=""
 
 auth = tweepy.OAuthHandler(consumer_key, consumer_secret)
+auth.secure = True
 auth.set_access_token(access_token, access_token_secret)
 
 api = tweepy.API(auth)
 
 # If the authentication was successful, you should
 # see the name of the account print out
-print api.me().name
+print(api.me().name)
 
 # If the application settings are set for "Read and Write" then
-# this line should tweet out the message to your account's 
+# this line should tweet out the message to your account's
 # timeline. The "Read and Write" setting is on https://dev.twitter.com/apps
-api.update_status('Updating using OAuth authentication via Tweepy!')
+api.update_status(status='Updating using OAuth authentication via Tweepy!')
